==> tgif-QPL-4.1.41.tar.gz: tgif-QPL-4.1.41/rmcast/rmmsg.h <==
/***************************************************************************
                             rmmsg.h
                             -------------------
    begin                : May 2001
    copyright            : (C) 2001 by Jorge Allyson Azevedo
                                       Milena Scanferla
                                       Magnos Martinello
                                       Daniel Sadoc
    email                : {allyson,milena,magnos,sadoc}@land.ufrj.br
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef MSG_H
#define MSG_H


#include <sys/types.h>
#include <sys/ipc.h>
#include <sys/msg.h>
#include <error.h>
#include <string.h>
#include <stdio.h>
#include <errno.h>


#ifndef MSG_QUEUE_HEADER_SIZE
    
#define MSG_QUEUE_HEADER_SIZE 2 /* number of bytes used to store the data size */
    
#endif    


extern int errno;

#define MAXOBN 20000
#define MAXPRIOR 10

#define QPERM 0660
#define QKEY_BASE (key_t) 0105


struct q_entry {
    long mtype;
    char mtext[MAXOBN+1];
};

int proc_obj(struct q_entry *msg);
int init_queue();
void remove_queues(int i);
int messageQueueEnter(char *objname, int len);

// int messageQueueServe();


#endif

==> tgif-QPL-4.1.42.tar.gz: tgif-QPL-4.1.42/rmcast/rmmsg.h <==
/***************************************************************************
                             rmmsg.h
                             -------------------
    begin                : May 2001
    copyright            : (C) 2001 by Jorge Allyson Azevedo
                                       Milena Scanferla
                                       Magnos Martinello
                                       Daniel Sadoc
    email                : {allyson,milena,magnos,sadoc}@land.ufrj.br
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public Licensee as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef MSG_H
#define MSG_H


#include <sys/types.h>
#include <sys/ipc.h>
#include <sys/msg.h>
#include <string.h>
#include <stdio.h>
#include <errno.h>
#include <stdlib.h>


#ifndef MSG_QUEUE_HEADER_SIZE
    
#define MSG_QUEUE_HEADER_SIZE 2 /* number of bytes used to store the data size */
    
#endif    


extern int errno;

#define MAXOBN 20000
#define MAXPRIOR 10

#define QPERM 0660
#define QKEY_BASE (key_t) 0105


struct q_entry {
    long mtype;
    char mtext[MAXOBN+1];
};

int init_queue();
void remove_queues(int i);
int messageQueueEnter(char *objname, int len);

/*FIXME lixo? int messageQueueServe(); */


#endif
